@@ -3,6 +3,19 @@
 __LIB_DIR__ = File.expand_path(File.dirname(__FILE__))
 $LOAD_PATH.unshift __LIB_DIR__ unless $LOAD_PATH.include?(__LIB_DIR__)
 
+# Use core
+require 'fog/core'
+
+# Previously treated as "core"
+# data exchange specific (to be extracted and used on a per provider basis)
+require 'fog/xml'
+require 'fog/json'
+require 'fog/core/parser'
+
+# deprecation wrappers (XML wrapped version)
+require 'fog/core/deprecated/connection'
+require 'fog/core/deprecated_connection_accessors'
+
 # any one of these can be required separately.
 # they all depend on fog/core for shared functionality.
 require 'fog/atmos'
@@ -14,6 +27,7 @@ require 'fog/clodo'
 require 'fog/digitalocean'
 require 'fog/dnsimple'
 require 'fog/dnsmadeeasy'
+require 'fog/fogdocker'
 require 'fog/dreamhost'
 require 'fog/dynect'
 require 'fog/ecloud'
@@ -30,9 +44,11 @@ require 'fog/local'
 require 'fog/bare_metal_cloud'
 require 'fog/ninefold'
 require 'fog/rackspace'
+require 'fog/rage4'
 require 'fog/riakcs'
 require 'fog/openstack'
 require 'fog/ovirt'
+require 'fog/sakuracloud'
 require 'fog/serverlove'
 require 'fog/storm_on_demand'
 require 'fog/terremark'
