@@ -1,5 +1,4 @@
-require 'fog/aws'
-require 'fog/dns'
+require 'fog/aws/core'
 
 module Fog
   module DNS
@@ -100,7 +99,7 @@ module Fog
           @scheme     = options[:scheme]      || 'https'
           @version    = options[:version]     || '2012-02-29'
 
-          @connection = Fog::Connection.new("#{@scheme}://#{@host}:#{@port}#{@path}", @persistent, @connection_options)
+          @connection = Fog::XML::Connection.new("#{@scheme}://#{@host}:#{@port}#{@path}", @persistent, @connection_options)
         end
 
         def reload
