@@ -1,4 +1,4 @@
-require 'fog/aws'
+require 'fog/aws/core'
 
 module Fog
   module AWS
@@ -88,7 +88,7 @@ module Fog
           @port       = options[:port]        || '443'
           @scheme     = options[:scheme]      || 'https'
 
-          @connection = Fog::Connection.new("#{@scheme}://#{@host}:#{@port}#{@path}", @persistent, @connection_options)
+          @connection = Fog::XML::Connection.new("#{@scheme}://#{@host}:#{@port}#{@path}", @persistent, @connection_options)
         end
 
         private
@@ -112,7 +112,6 @@ module Fog
           # defaults for all dynamodb requests
           params.merge!({
             :expects  => 200,
-            :host     => @host,
             :method   => :post,
             :path     => '/'
           })
