@@ -1,3 +1,5 @@
+require 'fog/aws/core'
+
 module Fog
   module AWS
     class Elasticache < Fog::Service
@@ -33,6 +35,10 @@ module Fog
       request :authorize_cache_security_group_ingress
       request :revoke_cache_security_group_ingress
 
+      request :create_cache_subnet_group
+      request :describe_cache_subnet_groups
+      request :delete_cache_subnet_group
+
       request :describe_events
 
       model_path 'fog/aws/models/elasticache'
@@ -42,6 +48,8 @@ module Fog
       collection :security_groups
       model :parameter_group
       collection :parameter_groups
+      model :subnet_group
+      collection :subnet_groups
 
       class Real
         include Fog::AWS::CredentialFetcher::ConnectionMethods
@@ -54,7 +62,7 @@ module Fog
           @path       = options[:path]      || '/'
           @port       = options[:port]      || 443
           @scheme     = options[:scheme]    || 'https'
-          @connection = Fog::Connection.new(
+          @connection = Fog::XML::Connection.new(
             "#{@scheme}://#{@host}:#{@port}#{@path}", options[:persistent]
           )
         end
@@ -89,8 +97,7 @@ module Fog
             :host               => @host,
             :path               => @path,
             :port               => @port,
-            #:version            => '2011-07-15'
-            :version            => '2012-11-15'
+            :version            => '2013-06-15'
           }
           )
 
@@ -100,7 +107,6 @@ module Fog
               :expects    => 200,
               :headers    => { 'Content-Type' => 'application/x-www-form-urlencoded' },
               :idempotent => idempotent,
-              :host       => @host,
               :method     => 'POST',
               :parser     => parser
             })
@@ -132,7 +138,17 @@ module Fog
               region_hash[key] = {
                 :clusters  => {}, # cache cluster data, indexed by cluster ID
                 :security_groups => {}, # security groups
-              }
+                :subnet_groups => {},
+                :parameter_groups => {"default.memcached1.4" => { "CacheParameterGroupFamily"=>"memcached1.4",
+                                                                  "Description"=>"Default parameter group for memcached1.4",
+                                                                  "CacheParameterGroupName"=>"default.memcached1.4"
+                                                                },
+                                      "default.redis2.6" =>     {"CacheParameterGroupFamily"=>"redis2.6",
+                                                                 "Description"=>"Default parameter group for redis2.6",
+                                                                 "CacheParameterGroupName"=>"default.redis2.6"
+                                                                }
+                                      }
+                                  }
             end
           end
         end
