@@ -4,14 +4,22 @@ module Fog
   module AWS
     class AutoScaling
       class Activities < Fog::Collection
-
         model Fog::AWS::AutoScaling::Activity
 
-        def all
+        attribute :filters
+
+        # Creates a new scaling policy.
+        def initialize(attributes={})
+          self.filters = attributes
+          super(attributes)
+        end
+
+        def all(filters = filters)
           data = []
           next_token = nil
+          self.filters = filters
           loop do
-            result = connection.describe_scaling_activities('NextToken' => next_token).body['DescribeScalingActivitiesResult']
+            result = service.describe_scaling_activities(filters.merge('NextToken' => next_token)).body['DescribeScalingActivitiesResult']
             data += result['Activities']
             next_token = result['NextToken']
             break if next_token.nil?
@@ -20,7 +28,7 @@ module Fog
         end
 
         def get(identity)
-          data = connection.describe_scaling_activities('ActivityId' => identity).body['DescribeScalingActivitiesResult']['Activities'].first
+          data = service.describe_scaling_activities('ActivityId' => identity).body['DescribeScalingActivitiesResult']['Activities'].first
           new(data) unless data.nil?
         end
 
