@@ -13,6 +13,8 @@ module Fog
         attribute :disk
         attribute :name
         attribute :ram
+        attribute :ebs_optimized_available
+        attribute :instance_store_volumes
 
       end
 
