@@ -23,17 +23,17 @@ module Fog
             filters = {'snapshot-id' => [*filters]}
           end
           self.filters = filters
-          data = connection.describe_snapshots(filters.merge!(options)).body
+          data = service.describe_snapshots(filters.merge!(options)).body
           load(data['snapshotSet'])
           if volume
             self.replace(self.select {|snapshot| snapshot.volume_id == volume.id})
           end
           self
         end
-        
+
         def get(snapshot_id)
           if snapshot_id
-            self.class.new(:connection => connection).all('snapshot-id' => snapshot_id).first
+            self.class.new(:service => service).all('snapshot-id' => snapshot_id).first
           end
         end
 
