@@ -12,14 +12,14 @@ module Fog
 
           def end_element(name)
             case name
-            when 'availabilityZone', 'currencyCode', 'instanceType', 'instanceTenancy', 'productDescription', 'reservedInstancesOfferingId'
+            when 'availabilityZone', 'currencyCode', 'instanceType', 'offeringType', 'instanceTenancy', 'productDescription', 'reservedInstancesOfferingId'
               @reserved_instances_offering[name] = value
             when 'duration'
               @reserved_instances_offering[name] = value.to_i
             when 'fixedPrice', 'usagePrice'
               @reserved_instances_offering[name] = value.to_f
             when 'item'
-              @response['reservedInstancesOfferingsSet'] << @reserved_instances_offering
+              @response['reservedInstancesOfferingsSet'] << @reserved_instances_offering unless @reserved_instances_offering.empty?
               @reserved_instances_offering = {}
             when 'requestId'
               @response[name] = value
