@@ -6,7 +6,7 @@ module Fog
         require 'fog/aws/parsers/rds/create_db_instance'
 
         # Create a db instance
-        # 
+        #
         # @param DBInstanceIdentifier [String] name of the db instance to modify
         # @param AllocatedStorage [Integer] Storage space, in GB
         # @param AutoMinorVersionUpgrade [Boolean] Indicates that minor version upgrades will be applied automatically to the DB Instance during the maintenance window
@@ -18,6 +18,7 @@ module Fog
         # @param DBSecurityGroups [Array] A list of DB Security Groups to authorize on this DB Instance
         # @param Engine [String] The name of the database engine to be used for this instance.
         # @param EngineVersion [String] The version number of the database engine to use.
+        # @param Iops [Integer] IOPS rate
         # @param MasterUsername [String] The db master user
         # @param MasterUserPassword [String] The new password for the DB Instance master user
         # @param MultiAZ [Boolean] Specifies if the DB Instance is a Multi-AZ deployment
@@ -27,10 +28,10 @@ module Fog
         # @param DBSubnetGroupName [String] The name, if any, of the VPC subnet for this RDS instance
         # @param PubliclyAcccesible [Boolean] Whether an RDS instance inside of the VPC subnet should have a public-facing endpoint
         # @param VpcSecurityGroups [Array] A list of VPC Security Groups to authorize on this DB instance
-        # 
+        #
         # @return [Excon::Response]:
         #   * body [Hash]:
-        # 
+        #
         # @see http://docs.amazonwebservices.com/AmazonRDS/latest/APIReference/API_CreateDBInstance.html
         def create_db_instance(db_name, options={})
 
@@ -98,11 +99,12 @@ module Fog
                  "DBInstanceStatus"=>"creating",
                  "BackupRetentionPeriod"=> options["BackupRetentionPeriod"] || 1,
                  "AllocatedStorage"=> options["AllocatedStorage"],
+                 "Iops" => options["Iops"],
                  "DBParameterGroups"=> # I think groups should be in the self.data method
                           [{"DBParameterGroupName"=>"default.mysql5.5",
                             "ParameterApplyStatus"=>"in-sync"}],
                  "DBSecurityGroups"=>
-                          [{"Status"=>"active", 
+                          [{"Status"=>"active",
                             "DBSecurityGroupName"=>"default"}],
                  "LicenseModel"=>"general-public-license",
                  "PreferredBackupWindow"=>"08:00-08:30",
