@@ -1,5 +1,4 @@
-require 'fog/bare_metal_cloud'
-require 'fog/compute'
+require 'fog/bare_metal_cloud/core'
 
 module Fog
   module Compute
@@ -59,7 +58,7 @@ module Fog
           @persistent = options[:persistent]  || false
           @port       = options[:port]        || 443
           @scheme     = options[:scheme]      || 'https'
-          @connection = Fog::Connection.new("#{@scheme}://#{@host}:#{@port}", @persistent, @connection_options)
+          @connection = Fog::XML::Connection.new("#{@scheme}://#{@host}:#{@port}", @persistent, @connection_options)
         end
 
         def reload
