@@ -5,6 +5,8 @@ class Joyent < Fog::Bin
       case key
       when :compute
         Fog::Compute::Joyent
+      when :analytics
+        Fog::Joyent::Analytics
       else
         raise ArgumentError, "Unrecognized service: #{key}"
       end
@@ -16,6 +18,8 @@ class Joyent < Fog::Bin
         when :compute
           Fog::Logger.warning("Joyent[:compute] is not recommended, use Compute[:joyent] for portability")
           Fog::Compute.new(:provider => 'Joyent')
+        when :analytics
+          Fog::Joyent::Analytics.new
         else
           raise ArgumentError, "Unrecognized service: #{key.inspect}"
         end
