@@ -6,26 +6,19 @@ module Fog
         # Gets record from given domain.
         #
         # ==== Parameters
-        # * domain<~String>
+        # * domain<~String> - domain name or numeric ID
         # * record_id<~String>
+        #
         # ==== Returns
         # * response<~Excon::Response>:
-        #   * record<~Hash>
-        #     * name<~String>
-        #     * ttl<~Integer>
-        #     * created_at<~String>
-        #     * special_type<~String>
-        #     * updated_at<~String>
-        #     * domain_id<~Integer>
-        #     * id<~Integer>
-        #     * content<~String>
-        #     * record_type<~String>
-        #     * prio<~Integer>
+        #   * body<~Hash>:
+        #     * 'record'<~Hash> The representation of the record.
         def get_record(domain, record_id)
-
-          request( :expects  => 200,
-                   :method   => "GET",
-                   :path     => "/domains/#{domain}/records/#{record_id}" )
+          request(
+            :expects  => 200,
+            :method   => "GET",
+            :path     => "/domains/#{domain}/records/#{record_id}"
+          )
         end
 
       end
@@ -34,7 +27,8 @@ module Fog
 
         def get_record(domain, record_id)
           response = Excon::Response.new
-          if self.data[:records].has_key? domain
+
+          if self.data[:records].has_key?(domain)
             response.status = 200
             response.body = self.data[:records][domain].detect { |record| record["record"]["id"] == record_id }
 
