@@ -6,24 +6,19 @@ module Fog
         # Get the list of records for the specific domain.
         #
         # ==== Parameters
-        # * domain<~String>
+        # * domain<~String> - domain name or numeric ID
+        #
         # ==== Returns
         # * response<~Excon::Response>:
-        #   * records<Array~>
-        #     * name<~String>
-        #     * ttl<~Integer>
-        #     * created_at<~String>
-        #     * special_type<~String>
-        #     * updated_at<~String>
-        #     * domain_id<~Integer>
-        #     * id<~Integer>
-        #     * content<~String>
-        #     * record_type<~String>
-        #     * prio<~Integer>
+        #   * body<~Hash>:
+        #     * <~Array>:
+        #       * 'record'<~Hash> The representation of the record.
         def list_records(domain)
-          request( :expects  => 200,
-                   :method   => "GET",
-                   :path     => "/domains/#{domain}/records" )
+          request(
+            :expects  => 200,
+            :method   => "GET",
+            :path     => "/domains/#{domain}/records"
+          )
         end
 
       end
