@@ -11,12 +11,12 @@ module Fog
 
         def all
           clear
-          data = connection.list_domains.body['list'].collect{|domain| {:id => domain}}
+          data = service.list_domains.body['list'].collect{|domain| {:id => domain}}
           load(data)
         end
 
         def get(zone_id)
-          data = connection.get_domain(zone_id).body
+          data = service.get_domain(zone_id).body
           data.merge!(:id => data['name'])
           new(data)
         rescue Fog::Service::NotFound
