@@ -3,29 +3,29 @@ require 'fog/ecloud/models/compute/task'
 module Fog
   module Compute
     class Ecloud
-
       class Tasks < Fog::Ecloud::Collection
 
         model Fog::Compute::Ecloud::Task
 
-        attribute :href, :aliases => :Href
+        identity :href
+        attribute :other_links, :aliases => :Links
+        attribute :total_count, :aliases => :TotalCount
 
         def all
-          check_href!
-          if data = connection.get_task_list(href).body[:Task]
-            load(data)
-          end
+          data = service.get_tasks(href).body
+          data = data[:Task] ? data[:Task] : data
+          load(data)
         end
 
         def get(uri)
-          if data = connection.get_task(uri)
+          if data = service.get_task(uri)
             new(data.body)
           end
         rescue Fog::Errors::NotFound
           nil
         end
-
       end
     end
   end
 end
+
