@@ -79,7 +79,7 @@ module Fog
         end
 
         def setup(credentials = {})
-          requires :public_ip_address, :username
+          requires :ssh_ip_address, :username
           require 'net/ssh'
 
           attrs = attributes.dup
@@ -100,7 +100,7 @@ module Fog
           # wait for glesys to be ready
           wait_for { sshable?(credentials) }
 
-          Fog::SSH.new(public_ip_address, username, credentials).run(commands)
+          Fog::SSH.new(ssh_ip_address, username, credentials).run(commands)
         end
 
         def ssh(command, options={}, &block)
