@@ -71,8 +71,8 @@ module Fog
         end
 
         def setup(credentials = {})
-          requires :identity, :public_ip_address, :public_key, :username
-          Fog::SSH.new(public_ip_address, username, credentials).run([
+          requires :identity, :ssh_ip_address, :public_key, :username
+          Fog::SSH.new(ssh_ip_address, username, credentials).run([
             %{mkdir .ssh},
             %{echo "#{public_key}" >> ~/.ssh/authorized_keys},
             %{passwd -l root},
