@@ -1,53 +1,90 @@
-require 'fog/google'
-require 'fog/compute'
+require 'fog/google/core'
 
 module Fog
   module Compute
     class Google < Fog::Service
 
       requires :google_project
-      requires :google_client_email
-      requires :google_key_location
+      recognizes :app_name, :app_version, :google_client_email, :google_key_location, :google_client
 
       request_path 'fog/google/requests/compute'
       request :list_servers
+      request :list_addresses
+      request :list_aggregated_addresses
       request :list_disks
       request :list_firewalls
       request :list_images
       request :list_machine_types
+      request :list_aggregated_machine_types
       request :list_networks
       request :list_zones
+      request :list_regions
       request :list_global_operations
+      request :list_region_operations
       request :list_zone_operations
       request :list_snapshots
+      request :list_http_health_checks
+      request :list_target_pools
+      request :list_forwarding_rules
+      request :list_routes
 
       request :get_server
+      request :get_address
       request :get_disk
       request :get_firewall
       request :get_image
       request :get_machine_type
       request :get_network
       request :get_zone
+      request :get_region
       request :get_snapshot
       request :get_global_operation
+      request :get_region_operation
       request :get_zone_operation
+      request :get_http_health_check
+      request :get_target_pool
+      request :get_target_pool_health
+      request :get_forwarding_rule
+      request :get_project
+      request :get_route
 
+      request :delete_address
       request :delete_disk
+      request :delete_snapshot
       request :delete_firewall
       request :delete_image
       request :delete_network
       request :delete_server
       request :delete_global_operation
+      request :delete_region_operation
       request :delete_zone_operation
+      request :delete_http_health_check
+      request :delete_target_pool
+      request :delete_forwarding_rule
+      request :delete_route
 
+      request :insert_address
       request :insert_disk
       request :insert_firewall
       request :insert_image
       request :insert_network
       request :insert_server
       request :insert_snapshot
+      request :insert_http_health_check
+      request :insert_target_pool
+      request :insert_forwarding_rule
+      request :insert_route
 
       request :set_metadata
+      request :set_tags
+      request :set_forwarding_rule_target
+
+      request :add_target_pool_instances
+      request :add_target_pool_health_checks
+
+      request :remove_target_pool_instances
+      request :remove_target_pool_health_checks
+      request :set_common_instance_metadata
 
       model_path 'fog/google/models/compute'
       model :server
@@ -62,6 +99,9 @@ module Fog
       model :disk
       collection :disks
 
+      model :address
+      collection :addresses
+
       model :operation
       collection :operations
 
@@ -71,12 +111,39 @@ module Fog
       model :zone
       collection :zones
 
+      model :region
+      collection :regions
+
+      model :http_health_check
+      collection :http_health_checks
+
+      model :target_pool
+      collection :target_pools
+
+      model :forwarding_rule
+      collection :forwarding_rules
+
+      model :project
+      collection :projects
+
+      model :firewall
+      collection :firewalls
+
+      model :network
+      collection :networks
+
+      model :route
+      collection :routes
+
       module Shared
         attr_reader :project, :api_version
 
         def shared_initialize(options = {})
           @project = options[:google_project]
-          @api_version = 'v1beta16'
+          @api_version = 'v1'
+          base_url = 'https://www.googleapis.com/compute/'
+          @api_url = base_url + api_version + '/projects/'
+          @default_network = 'default'
         end
 
         def build_excon_response(body, status=200)
@@ -84,7 +151,11 @@ module Fog
           response.body = body
           if response.body and response.body["error"]
             response.status = response.body["error"]["code"]
-            msg = response.body["error"]["errors"].map{|error| error["message"]}.join(", ")
+            if response.body["error"]["errors"]
+              msg = response.body["error"]["errors"].map{|error| error["message"]}.join(", ")
+            else
+              msg = "Error [#{response.body["error"]["code"]}]: #{response.body["error"]["message"] || "GCE didn't return an error message"}"
+            end
             case response.status
             when 404
               raise Fog::Errors::NotFound.new(msg)
@@ -114,7 +185,6 @@ module Fog
           end
           result
         end
-
       end
 
       class Mock
@@ -144,7 +214,6 @@ module Fog
                     "name" => "centos-6-2-v20120621",
                     "description" => "CentOS 6.2; Created Thu, 21 Jun 2012 14:22:21 +0000",
                     "sourceType" => "RAW",
-                    "preferredKernel" => "https://www.googleapis.com/compute/#{api_version}/projects/google/global/kernels/gce-20120621",
                     "rawDisk" => {
                       "containerType" => "TAR",
                       "source" => ""
@@ -163,7 +232,6 @@ module Fog
                     "name" => "centos-6-v20120912",
                     "description" => "CentOS 6; Created Wed, 12 Sep 2012 00:00:00 +0000",
                     "sourceType" => "RAW",
-                    "preferredKernel" => "https://www.googleapis.com/compute/#{api_version}/projects/google/global/kernels/gce-v20120912",
                     "rawDisk" => {
                       "containerType" => "TAR",
                       "source" => ""
@@ -182,7 +250,6 @@ module Fog
                     "name" => "centos-6-v20121106",
                     "description" => "SCSI-enabled CentOS 6; Created Tue, 06 Nov 2012 00:00:00 +0000",
                     "sourceType" => "RAW",
-                    "preferredKernel" => "https://www.googleapis.com/compute/#{api_version}/projects/google/global/kernels/gce-v20121106",
                     "rawDisk" => {
                       "containerType" => "TAR",
                       "source" => ""
@@ -202,7 +269,6 @@ module Fog
                     "name" => "debian-6-squeeze-v20130816",
                     "description" => "Debian GNU/Linux 6.0.7 (squeeze) built on 2013-08-16",
                     "sourceType" => "RAW",
-                    "preferredKernel" => "https://www.googleapis.com/compute/#{api_version}/projects/google/global/kernels/gce-v20130813",
                     "rawDisk" => {
                       "containerType" => "TAR",
                       "source" => ""
@@ -217,7 +283,6 @@ module Fog
                     "name" => "debian-7-wheezy-v20130816",
                     "description" => "Debian GNU/Linux 7.1 (wheezy) built on 2013-08-16",
                     "sourceType" => "RAW",
-                    "preferredKernel" => "https://www.googleapis.com/compute/#{api_version}/projects/google/global/kernels/gce-v20130813",
                     "rawDisk" => {
                       "containerType" => "TAR",
                       "source" => ""
@@ -232,12 +297,26 @@ module Fog
                     "name" => "debian-7-wheezy-v20131014",
                     "description" => "Debian GNU/Linux 7.1 (wheezy) built on 2013-10-14",
                     "sourceType" => "RAW",
-                    "preferredKernel" => "https://www.googleapis.com/compute/#{api_version}/projects/google/global/kernels/gce-v20130813",
                     "rawDisk" => {
                       "containerType" => "TAR",
                       "source" => ""
                     },
                     "status" => "READY"
+                  },
+                  "debian-7-wheezy-v20140408" => {
+                    "kind" => "compute#image",
+                    "selfLink" => "https://www.googleapis.com/compute/#{api_version}/projects/debian-cloud/global/images/debian-7-wheezy-v20140408",
+                    "id" => "17312518942796567788",
+                    "creationTimestamp" => "2013-11-25T15:17:00.436-08:00",
+                    "name" => "debian-7-wheezy-v20131120",
+                    "description" => "Debian GNU/Linux 7.2 (wheezy) built on 2013-11-20",
+                    "sourceType" => "RAW",
+                    "rawDisk" => {
+                      "containerType" => "TAR",
+                      "source" => ""
+                    },
+                    "status" => "READY",
+                    "archiveSizeBytes" => "341857472"
                   }
                 }
               }
@@ -252,7 +331,6 @@ module Fog
                     "name" => "centos-6-v20130813",
                     "description" => "SCSI-enabled CentOS 6; Created Tue, 13 Aug 2013 00:00:00 +0000",
                     "sourceType" => "RAW",
-                    "preferredKernel" => "https://www.googleapis.com/compute/#{api_version}/projects/google/global/kernels/gce-v20130813",
                     "rawDisk" => {
                       "containerType" => "TAR",
                       "source" => ""
@@ -273,8 +351,6 @@ module Fog
                     "name" => "fog-1380196541",
                     "tags" => { "fingerprint" => "42WmSpB8rSM=" },
                     "machineType" => "https://www.googleapis.com/compute/#{api_version}/projects/#{key}/zones/us-central1-a/machineTypes/n1-standard-1",
-                    "image" => "https://www.googleapis.com/compute/#{api_version}/projects/centos-cloud/global/images/centos-6-v20130813",
-                    "kernel" => "https://www.googleapis.com/compute/#{api_version}/projects/google/global/kernels/gce-v20130813",
                     "canIpForward" => false,
                     "networkInterfaces" => [
                       {
@@ -295,8 +371,11 @@ module Fog
                       {
                         "kind" => "compute#attachedDisk",
                         "index" => 0,
-                        "type" => "SCRATCH",
-                        "mode" => "READ_WRITE"
+                        "type" => "PERSISTENT",
+                        "mode" => "READ_WRITE",
+                        "source" => "https://www.googleapis.com/compute/#{api_version}/projects/#{key}/zones/us-central1-a/disks/fog-1",
+                        "deviceName" => "persistent-disk-0",
+                        "boot" => true
                       }
                     ],
                     "metadata" => {
@@ -771,7 +850,30 @@ module Fog
                   }
                 end,
                 :images => {},
-                :disks => {},
+                :disks => {
+                  "fog-1" => {
+                    "kind" => "compute#disk",
+                    "id" => "3338131294770784461",
+                    "creationTimestamp" => "2013-12-18T19:47:10.583-08:00",
+                    "zone" => "https://www.googleapis.com/compute/#{api_version}/projects/#{key}/zones/us-central1-a",
+                    "status" => "READY",
+                    "name" => "fog-1",
+                    "sizeGb" => "10",
+                    "selfLink" => "https://www.googleapis.com/compute/#{api_version}/projects/#{key}/zones/us-central1-a/disks/fog-1",
+                    "sourceImage" => "https://www.googleapis.com/compute/#{api_version}/projects/debian-cloud/global/images/debian-7-wheezy-v20131120",
+                    "sourceImageId" => "17312518942796567788"
+                  },
+                  "fog-2" => {
+                    "kind" => "compute#disk",
+                    "id" => "3338131294770784462",
+                    "creationTimestamp" => "2013-12-18T19:47:10.583-08:00",
+                    "zone" => "https://www.googleapis.com/compute/#{api_version}/projects/#{key}/zones/us-central1-a",
+                    "status" => "READY",
+                    "name" => "fog-2",
+                    "sizeGb" => "10",
+                    "selfLink" => "https://www.googleapis.com/compute/#{api_version}/projects/#{key}/zones/us-central1-a/disks/fog-1"
+                  }
+                },
                 :operations => {}
               }
             end
@@ -782,7 +884,7 @@ module Fog
           @data = nil
         end
 
-        def data(project = @project)
+        def data(project=@project)
           self.class.data(api_version)[project]
         end
 
@@ -800,28 +902,77 @@ module Fog
         include Collections
         include Shared
 
-        def initialize(options)
-          base_url = 'https://www.googleapis.com/compute/'
-          api_scope_url = 'https://www.googleapis.com/auth/compute'
-          shared_initialize(options)
+        attr_accessor :client
+        attr_reader :compute, :api_url
 
-          google_client_email = options[:google_client_email]
-          @api_url = base_url + api_version + '/projects/'
+        def initialize(options)
 
           # NOTE: loaded here to avoid requiring this as a core Fog dependency
           begin
             require 'google/api_client'
-          rescue LoadError
+          rescue LoadError => error
             Fog::Logger.warning("Please install the google-api-client gem before using this provider.")
+            raise error
           end
-          key = ::Google::APIClient::KeyUtils.load_from_pkcs12(File.expand_path(options[:google_key_location]), 'notasecret')
+          shared_initialize(options)
 
-          @client = ::Google::APIClient.new({
-            :application_name => "fog",
-            :application_version => Fog::VERSION,
-          })
+          if !options[:google_client].nil?
+            @client = options[:google_client]
+          end
 
-          @client.authorization = Signet::OAuth2::Client.new({
+          if @client.nil?
+            if !options[:google_client_email].nil? and !options[:google_key_location].nil?
+              @client = self.new_pk12_google_client(
+                options[:google_client_email],
+                File.expand_path(options[:google_key_location]),
+                options[:app_name],
+                options[:app_verion])
+            else
+              Fog::Logger.debug("Fog::Compute::Google.client has not been initialized nor are the :google_client_email and :google_key_location options set, so we can not create one for you.")
+              raise ArgumentError.new("No Google API Client has been initialized.")
+            end
+          end
+
+          # We want to always mention we're using Fog.
+          if @client.user_agent.nil? or @client.user_agent.empty?
+            @client.user_agent = ""
+          elsif !@client.user_agent.include? "fog"
+            @client.user_agent += "fog/#{Fog::VERSION}"
+          end
+
+          @compute = @client.discovered_api('compute', api_version)
+        end
+
+        # Public: Create a Google::APIClient with a pkcs12 key and a user email.
+        #
+        # google_client_email - an @developer.gserviceaccount.com email address to use.
+        # google_key_location - an absolute location to a pkcs12 key file.
+        # app_name - an optional string to set as the app name in the user agent.
+        # app_version - an optional string to set as the app version in the user agent.
+        #
+        # Returns a new Google::APIClient
+        def new_pk12_google_client(google_client_email, google_key_location, app_name=nil, app_version=nil)
+          # The devstorage scope is needed to be able to insert images
+          # devstorage.read_only scope is not sufficient like you'd hope
+          api_scope_url = 'https://www.googleapis.com/auth/compute https://www.googleapis.com/auth/devstorage.read_write'
+
+          user_agent = ""
+          if app_name
+            user_agent = "#{app_name}/#{app_version || '0.0.0'} "
+          end
+          user_agent += "fog/#{Fog::VERSION}"
+
+          api_client_options = {
+            # https://github.com/google/google-api-ruby-client/blob/master/lib/google/api_client.rb#L98
+            :application_name => "suppress warning",
+            # https://github.com/google/google-api-ruby-client/blob/master/lib/google/api_client.rb#L100
+            :user_agent => user_agent
+          }
+          local_client = ::Google::APIClient.new(api_client_options)
+
+          key = ::Google::APIClient::KeyUtils.load_from_pkcs12(google_key_location, 'notasecret')
+
+          local_client.authorization = Signet::OAuth2::Client.new({
             :audience => 'https://accounts.google.com/o/oauth2/token',
             :auth_provider_x509_cert_url => "https://www.googleapis.com/oauth2/v1/certs",
             :client_x509_cert_url => "https://www.googleapis.com/robot/v1/metadata/x509/#{google_client_email}",
@@ -831,9 +982,9 @@ module Fog
             :token_credential_uri => 'https://accounts.google.com/o/oauth2/token',
           })
 
-          @client.authorization.fetch_access_token!
-          @compute = @client.discovered_api('compute', api_version)
-          @default_network = 'default'
+          local_client.authorization.fetch_access_token!
+
+          return local_client
         end
 
         def build_result(api_method, parameters, body_object=nil)
@@ -854,9 +1005,8 @@ module Fog
         # result = Google::APIClient::Result
         # returns Excon::Response
         def build_response(result)
-          build_excon_response(result.body.nil? ? nil : Fog::JSON.decode(result.body), result.status)
+          build_excon_response(result.body.nil? || result.body.empty? ? nil : Fog::JSON.decode(result.body), result.status)
         end
-
       end
 
       RUNNING = 'RUNNING'
