@@ -1,9 +1,20 @@
 def test
   connection = Fog::Compute.new({ :provider => "Google" })
 
+  name = "fog-smoke-test-#{Time.now.to_i}"
+
+  disk = connection.disks.create({
+    :name => name,
+    :size_gb => 10,
+    :zone_name => 'us-central1-a',
+    :source_image => 'debian-7-wheezy-v20131120',
+  })
+
+  disk.wait_for { disk.ready? }
+
   server = connection.servers.create(defaults = {
     :name => "fog-smoke-test-#{Time.now.to_i}",
-    :image_name => "debian-7-wheezy-v20130522",
+    :disks => [disk],
     :machine_type => "n1-standard-1",
     :zone_name => "us-central1-a",
     :private_key_path => File.expand_path("~/.ssh/id_rsa"),
@@ -34,5 +45,5 @@ def test
   end
 
   raise "Could not bootstrap sshable server." unless server.ssh("whoami")
-  raise "Cloud note delete server." unless server.destroy
+  raise "Could not delete server." unless server.destroy
 end
