@@ -4,7 +4,7 @@ module Fog
 
       class Mock
 
-        def insert_network(network_name, ip_range)
+        def insert_network(network_name, ip_range, options = {})
           Fog::Mock.not_implemented
         end
 
@@ -12,7 +12,7 @@ module Fog
 
       class Real
 
-        def insert_network(network_name, ip_range)
+        def insert_network(network_name, ip_range, options = {})
           api_method = @compute.networks.insert
           parameters = {
             'project' => @project,
@@ -22,8 +22,10 @@ module Fog
             'IPv4Range' => ip_range
           }
 
-          result = self.build_result(api_method, parameters,
-                                     body_object=body_object)
+          body_object['description'] = options[:description] if options[:description]
+          body_object['gatewayIPv4'] = options[:gateway_ipv4] if options[:gateway_ipv4]
+
+          result = self.build_result(api_method, parameters, body_object)
           response = self.build_response(result)
         end
 
