@@ -10,12 +10,12 @@ module Fog
         model Fog::Compute::IBM::Vlan
 
         def all
-          load(connection.list_vlans.body['vlan'])
+          load(service.list_vlans.body['vlan'])
         end
 
         def get(vlan_id)
           begin
-            vlan = connection.list_vlans.body
+            vlan = service.list_vlans.body
             new(vlan['vlan'].find{|vlan| vlan['id'] == vlan_id.to_s })
           rescue Fog::Compute::IBM::NotFound
             nil
