@@ -135,7 +135,7 @@ module Fog
         end
 
         def ssh(commands)
-          requires :public_ip_address, :username
+          requires :ssh_ip_address, :username
 
           ssh_options={}
           ssh_options[:password] = password unless password.nil?
@@ -153,19 +153,19 @@ module Fog
 
         # Transfers a file
         def scp(local_path, remote_path, upload_options = {})
-          requires :public_ip_address, :username
+          requires :ssh_ip_address, :username
 
           scp_options = {}
           scp_options[:password] = password unless self.password.nil?
           scp_options[:key_data] = [private_key] if self.private_key
           scp_options[:proxy]= ssh_proxy unless self.ssh_proxy.nil?
 
-          Fog::SCP.new(public_ip_address, username, scp_options).upload(local_path, remote_path, upload_options)
+          Fog::SCP.new(ssh_ip_address, username, scp_options).upload(local_path, remote_path, upload_options)
         end
 
         # Sets up a new key
         def setup(credentials = {})
-          requires :public_key, :public_ip_address, :username
+          requires :public_key, :ssh_ip_address, :username
 
           credentials[:proxy]= ssh_proxy unless ssh_proxy.nil?
           credentials[:password] = password unless self.password.nil?
@@ -184,7 +184,7 @@ module Fog
           Timeout::timeout(360) do
             begin
               Timeout::timeout(8) do
-                Fog::SSH.new(public_ip_address, username, credentials.merge(:timeout => 4)).run('pwd')
+                Fog::SSH.new(ssh_ip_address, username, credentials.merge(:timeout => 4)).run('pwd')
               end
             rescue Errno::ECONNREFUSED
               sleep(2)
@@ -193,7 +193,7 @@ module Fog
               retry
             end
           end
-          Fog::SSH.new(public_ip_address, username, credentials).run(commands)
+          Fog::SSH.new(ssh_ip_address, username, credentials).run(commands)
         end
 
         def update_display attrs = {}
