@@ -1,5 +1,4 @@
-require 'fog/linode'
-require 'fog/compute'
+require 'fog/linode/core'
 
 module Fog
   module Compute
@@ -36,7 +35,7 @@ module Fog
       request :linode_disk_list
       request :linode_disk_delete
       request :linode_disk_createfromdistribution
-      request :linode_disk_createfromstackscript     
+      request :linode_disk_createfromstackscript
       request :linode_ip_list
       request :linode_ip_addprivate
       request :linode_config_list
@@ -49,7 +48,7 @@ module Fog
       request :linode_shutdown
       request :linode_update
       request :stackscript_list
-      # request :linode_resize      
+      # request :linode_resize
 
       class Mock
 
@@ -84,7 +83,7 @@ module Fog
           @host   = options[:host]    || "api.linode.com"
           @port   = options[:port]    || 443
           @scheme = options[:scheme]  || 'https'
-          @connection = Fog::Connection.new("#{@scheme}://#{@host}:#{@port}", options[:persistent])
+          @connection = Fog::XML::Connection.new("#{@scheme}://#{@host}:#{@port}", options[:persistent])
         end
 
         def reload
