@@ -13,9 +13,9 @@ module Fog
 
         private
         def datacenters(id=nil)
-          connection.avail_datacenters.body['DATA'].map { |datacenter| map_datacenter datacenter }
+          service.avail_datacenters.body['DATA'].map { |datacenter| map_datacenter datacenter }
         end
-        
+
         def map_datacenter(datacenter)
           datacenter = datacenter.each_with_object({}) { |(k, v), h| h[k.downcase.to_sym] = v  }
           datacenter.merge! :id => datacenter[:datacenterid], :name => datacenter[:location]
