@@ -21,14 +21,15 @@ module Fog
         attribute :links
 
         def initialize(attributes)
-          @connection = attributes[:connection]
+          # Old 'connection' is renamed as service and should be used instead
+          prepare_service_value(attributes)
           super
         end
 
         def metadata
           @metadata ||= begin
             Fog::Compute::OpenStack::Metadata.new({
-              :connection => connection,
+              :service => service,
               :parent => self
             })
           end
@@ -42,7 +43,7 @@ module Fog
 
         def destroy
           requires :id
-          connection.delete_image(id)
+          service.delete_image(id)
           true
         end
 
