@@ -6,7 +6,7 @@ module Fog
 
         def update_meta(collection_name, parent_id, key, value)
           request(
-            :body     => MultiJson.encode({ 'meta' => { key => value }}),
+            :body     => Fog::JSON.encode({ 'meta' => {key => value}}),
             :expects  => 200,
             :method   => 'PUT',
             :path     => "#{collection_name}/#{parent_id}/metadata/#{key}"
@@ -22,17 +22,18 @@ module Fog
           if collection_name == "images" then
             if not list_images_detail.body['images'].detect {|_| _['id'] == parent_id}
               raise Fog::Compute::OpenStack::NotFound
-            end 
+            end
           end
 
           if collection_name == "servers" then
             if not list_servers_detail.body['servers'].detect {|_| _['id'] == parent_id}
               raise Fog::Compute::OpenStack::NotFound
-            end 
+            end
           end
 
+          #FIXME join w/ existing metadata here
           response = Excon::Response.new
-          response.body = { "meta" => { key => value } }
+          response.body = { "metadata" => {key => value} }
           response.status = 200
           response
 
