@@ -15,7 +15,7 @@ module Fog
       class Mock
         def delete_router(router_id)
           response = Excon::Response.new
-          if list_routers.body['routers'].map { |r| r['id'] }.include? router_id
+          if list_routers.body['routers'].find { |r| r[:id] == router_id }
             self.data[:routers].delete(router_id)
             response.status = 204
             response
