@@ -12,17 +12,17 @@ module Fog
 
         def destroy
           requires :identity, :load_balancer
-          connection.delete_access_rule(load_balancer.identity, identity)
+          service.delete_access_rule(load_balancer.identity, identity)
           true
         end
 
         def save
-          raise Fog::Errors::Error.new('Resaving an existing object may create a duplicate') if identity
+          raise Fog::Errors::Error.new('Resaving an existing object may create a duplicate') if persisted?
           requires :load_balancer, :address, :type
-          connection.create_access_rule(load_balancer.id, address, type)
+          service.create_access_rule(load_balancer.id, address, type)
 
           #Unfortunately, access rules creation doesn't return an ID, we require a subsequent list call and comparison
-          data = connection.list_access_rules(load_balancer.id).body['accessList'].select do |ar|
+          data = service.list_access_rules(load_balancer.id).body['accessList'].select do |ar|
             ar['address'] == address && ar['type'] == type
           end.first
           merge_attributes(data)
