@@ -26,7 +26,7 @@ module Fog
         # @note This value does not persist and will need to be specified each time a directory is created or retrieved
         # @see Directories#get
         attribute :cdn_cname
-        
+
         # @!attribute [w] public
         # Required for compatibility with other Fog providers. Not Used.
         attr_writer :public
@@ -45,7 +45,7 @@ module Fog
           end
           attributes[:metadata]
         end
-        
+
         # Retrieve directory metadata
         # @return [Fog::Storage::Rackspace::Metadata] metadata key value pairs.
         def metadata
@@ -100,7 +100,7 @@ module Fog
           end
           @public
         end
-        
+
         # Reload directory with latest data from Cloud Files
         # @return [Fog::Storage::Rackspace::Directory] returns itself
         # @raise [Fog::Storage::Rackspace::NotFound] - HTTP 404
@@ -113,7 +113,7 @@ module Fog
           @files = nil
           super
         end
-        
+
         # Returns the public url for the directory.
         # If the directory has not been published to the CDN, this method will return nil as it is not publically accessible. This method will return the approprate
         # url in the following order:
@@ -132,7 +132,7 @@ module Fog
           return urls[:ssl_uri] if service.ssl?
           cdn_cname || urls[:uri]
         end
-        
+
         # URL used to stream video to iOS devices. Cloud Files will auto convert to the approprate format.
         # @return [String] iOS URL
         # @raise [Fog::Storage::Rackspace::NotFound] - HTTP 404
@@ -143,7 +143,7 @@ module Fog
         def ios_url
           urls[:ios_uri]
         end
-        
+
         # URL used to stream resources
         # @return [String] streaming url
         # @raise [Fog::Storage::Rackspace::NotFound] - HTTP 404
@@ -166,26 +166,29 @@ module Fog
         def save
           requires :key
           create_or_update_container
-          raise Fog::Storage::Rackspace::Error.new("Directory can not be set as :public without a CDN provided") if public? && !cdn_enabled?
-          @urls = service.cdn.publish_container(self, public?)
+          if cdn_enabled?
+            @urls = service.cdn.publish_container(self, public?)
+          else
+            raise Fog::Storage::Rackspace::Error.new("Directory can not be set as :public without a CDN provided") if public?
+          end
           true
         end
-        
+
         private
-        
+
         def cdn_enabled?
           service.cdn && service.cdn.enabled?
         end
-        
+
         def urls
-          requires :key          
+          requires :key
           return {} unless cdn_enabled?
           @urls ||= service.cdn.urls(self)
         end
-           
+
         def create_or_update_container
-          headers = attributes[:metadata].nil? ? {} : metadata.to_headers           
-          service.put_container(key, headers)        
+          headers = attributes[:metadata].nil? ? {} : metadata.to_headers
+          service.put_container(key, headers)
         end
       end
     end
