@@ -36,7 +36,7 @@ module Fog
         # @return [String] string containing a list of space delimited URLs
         # @see http://docs.rackspace.com/files/api/v1/cf-devguide/content/CORS_Container_Header-d1e1300.html
         attribute :access_control_allow_origin, :aliases => ['Access-Control-Allow-Origin']
-        
+
         # @!attribute [rw] origin
         # @return [String] The origin is the URI of the object's host.
         # @see http://docs.rackspace.com/files/api/v1/cf-devguide/content/CORS_Container_Header-d1e1300.html
@@ -47,6 +47,18 @@ module Fog
         # @see http://docs.rackspace.com/files/api/v1/cf-devguide/content/Enabling_File_Compression_with_the_Content-Encoding_Header-d1e2198.html
         attribute :content_encoding, :aliases => 'Content-Encoding'
 
+        # @!attribute [rw] delete_at
+        # A Unix Epoch Timestamp, in integer form, representing the time when this object will be automatically deleted.
+        # @return [Integer] the unix epoch timestamp of when this object will be automatically deleted
+        # @see http://docs.rackspace.com/files/api/v1/cf-devguide/content/Expiring_Objects-e1e3228.html
+        attribute :delete_at, :aliases => ['X-Delete-At']
+
+        # @!attribute [rw] delete_after
+        # A number of seconds representing how long from now this object will be automatically deleted.
+        # @return [Integer] the number of seconds until this object will be automatically deleted
+        # @see http://docs.rackspace.com/files/api/v1/cf-devguide/content/Expiring_Objects-e1e3228.html
+        attribute :delete_after, :aliases => ['X-Delete-After']
+
         # @!attribute [r] directory
         # @return [Fog::Storage::Rackspace::Directory] directory containing file
         attr_accessor :directory
@@ -121,13 +133,13 @@ module Fog
           end
           attributes[:metadata]
         end
-        
+
         # File metadata
         # @return [Fog::Storage::Rackspace::Metadata] metadata key value pairs.
         def metadata
           attributes[:metadata] ||= Fog::Storage::Rackspace::Metadata.new(self)
         end
-        
+
         # Required for compatibility with other Fog providers. Not Used.
         def owner=(new_owner)
           if new_owner
@@ -165,7 +177,7 @@ module Fog
         def public?
           directory.public?
         end
-        
+
 
         # Get a url for file.
         #
@@ -201,7 +213,7 @@ module Fog
         def public_url
           Files::file_url directory.public_url, key
         end
-        
+
         # URL used to stream video to iOS devices without needing to convert your video
         # @return [String] iOS URL
         # @raise [Fog::Storage::Rackspace::NotFound] - HTTP 404
@@ -212,7 +224,7 @@ module Fog
         def ios_url
           Files::file_url directory.ios_url, key
         end
-        
+
         # URL used to stream resources
         # @return [String] streaming url
         # @raise [Fog::Storage::Rackspace::NotFound] - HTTP 404
@@ -222,8 +234,8 @@ module Fog
         # @see http://docs.rackspace.com/files/api/v1/cf-devguide/content/Streaming-CDN-Enabled_Containers-d1f3721.html
         def streaming_url
           Files::file_url directory.streaming_url, key
-        end      
-        
+        end
+
         # Immediately purge file from the CDN network
         # @raise [Fog::Storage::Rackspace::NotFound] - HTTP 404
         # @raise [Fog::Storage::Rackspace::BadRequest] - HTTP 400
@@ -254,11 +266,13 @@ module Fog
           options['Content-Disposition'] = content_disposition if content_disposition
           options['Etag'] = etag if etag
           options['Content-Encoding'] = content_encoding if content_encoding
+          options['X-Delete-At'] = delete_at if delete_at
+          options['X-Delete-After'] = delete_after if delete_after
           options.merge!(metadata.to_headers)
 
           data = service.put_object(directory.key, key, body, options)
           update_attributes_from(data)
-          
+
           self.content_length = Fog::Storage.get_body_size(body)
           self.content_type ||= Fog::Storage.get_content_type(body)
           true
