@@ -1,8 +1,8 @@
 module Fog
   module Rackspace
     class Queues
-      class Real
 
+      class Real
         # This operation creates a new queue.
         # The body of the request is empty.
         #
@@ -22,6 +22,20 @@ module Fog
           )
         end
       end
+
+      class Mock
+        def create_queue(queue_name)
+          raise MethodNotAllowed.new if queue_name.nil? || queue_name.empty?
+
+          existed = ! mock_queue(queue_name).nil?
+          add_queue(queue_name) unless existed
+
+          response = Excon::Response.new
+          response.status = existed ? 201 : 204
+          response
+        end
+      end
+
     end
   end
 end
