@@ -1,6 +1,7 @@
 module Fog
   module Rackspace
     class Queues
+
       class Real
 
         # This operation immediately deletes a queue and all of its existing messages.
@@ -19,7 +20,18 @@ module Fog
             :path => "queues/#{queue_name}"
           )
         end
+
       end
+
+      class Mock
+        def delete_queue(queue_name)
+          data.delete(queue_name)
+          response = Excon::Response.new
+          response.status = 204
+          response
+        end
+      end
+
     end
   end
 end
