@@ -1,6 +1,7 @@
 module Fog
   module Rackspace
     class Queues
+
       class Real
 
         # This operation posts the specified message or messages.
@@ -20,7 +21,23 @@ module Fog
             :path => "queues/#{queue_name}/claims/#{claim_id}"
           )
         end
+
       end
+
+      class Mock
+        def update_claim(queue_name, claim_id, ttl)
+          queue = mock_queue!(queue_name)
+          claim = queue.claim!(claim_id)
+
+          claim.touch!
+          claim.ttl = ttl
+
+          response = Excon::Response.new
+          response.status = 204
+          response
+        end
+      end
+
     end
   end
 end
