@@ -1,6 +1,7 @@
 module Fog
   module Storage
     class Rackspace
+
       class Real
 
         # Delete an existing container
@@ -20,6 +21,20 @@ module Fog
         end
 
       end
+
+      class Mock
+        def delete_container(name)
+          c = mock_container! name
+
+          raise Excon::Errors::Conflict.new 'Conflict' unless c.empty?
+          remove_container name
+
+          response = Excon::Response.new
+          response.status = 204
+          response
+        end
+      end
+
     end
   end
 end
