@@ -1,6 +1,7 @@
 module Fog
   module Storage
     class Rackspace
+
       class Real
 
         # Delete an existing object
@@ -21,6 +22,19 @@ module Fog
         end
 
       end
+
+      class Mock
+        def delete_object(container, object)
+          c = mock_container! container
+          c.mock_object! object
+          c.remove_object object
+
+          response = Excon::Response.new
+          response.status = 204
+          response
+        end
+      end
+
     end
   end
 end
