@@ -1,6 +1,7 @@
 module Fog
   module Storage
     class Rackspace
+
       class Real
 
         # Get details for container and total bytes stored
@@ -43,6 +44,30 @@ module Fog
         end
 
       end
+
+      class Mock
+        def get_container(container, options = {})
+          c = mock_container! container
+
+          results = []
+          c.objects.each do |key, mock_file|
+            results << {
+              "hash" => mock_file.hash,
+              "last_modified" => mock_file.last_modified.strftime('%Y-%m-%dT%H:%M:%S.%L'),
+              "bytes" => mock_file.bytes_used,
+              "name" => key,
+              "content_type" => mock_file.content_type
+            }
+          end
+
+          response = Excon::Response.new
+          response.status = 200
+          response.headers = c.to_headers
+          response.body = results
+          response
+        end
+      end
+
     end
   end
 end
