@@ -1,6 +1,7 @@
 module Fog
   module Storage
     class Rackspace
+
       class Real
 
         # Get details for object
@@ -27,6 +28,31 @@ module Fog
         end
 
       end
+
+      class Mock
+        def get_object(container, object, &block)
+          c = mock_container! container
+          o = c.mock_object! object
+
+          body, size = "", 0
+
+          o.each_part do |part|
+            body << part.body
+            size += part.bytes_used
+          end
+
+          if block_given?
+            # Just send it all in one chunk.
+            block.call(body, 0, size)
+          end
+
+          response = Excon::Response.new
+          response.body = body
+          response.headers = o.to_headers
+          response
+        end
+      end
+
     end
   end
 end
