@@ -2,8 +2,7 @@ module Fog
   module Storage
     class Rackspace
 
-      class Real
-
+      module Common
         # Get an expiring object http url from Cloud Files
         #
         # ==== Parameters
@@ -25,6 +24,14 @@ module Fog
         end
       end
 
+      class Real
+        include Common
+      end
+
+      class Mock
+        include Common
+      end
+
     end
   end
-end
\ No newline at end of file
+end
