@@ -27,6 +27,18 @@ module Fog
         end
 
       end
+
+      class Mock
+        def head_container(container)
+          c = mock_container! container
+
+          response = Excon::Response.new
+          response.status = 204
+          response.headers = c.to_headers
+          response
+        end
+      end
+
     end
   end
 end
