@@ -1,6 +1,5 @@
-require 'fog/storm_on_demand'
+require 'fog/storm_on_demand/core'
 require 'fog/storm_on_demand/shared'
-require 'fog/account'
 
 module Fog
   module Account
