@@ -1,5 +1,4 @@
-require 'fog/billing'
-require 'fog/storm_on_demand'
+require 'fog/storm_on_demand/core'
 require 'fog/storm_on_demand/shared'
 
 module Fog
@@ -58,4 +57,4 @@ module Fog
       end
     end
   end
-end
\ No newline at end of file
+end
